@@ -14,7 +14,9 @@ default_config = {
     'CONFIRM_UNSAVED_CHANGES': True,
     'SHOW_MULTIPART_UPLOADING': True,
     'ENABLE_IMAGES_PREVIEW': True,
+    'COLLAPSABLE_USER_AREA': False,
     'CHANGELIST_FILTERS_IN_MODAL': False,
+    'CHANGELIST_FILTERS_ALWAYS_OPEN': False,
     'MENU_ALWAYS_COLLAPSED': False,
     'GRAVATAR_DEFAULT_IMG': 'retro',
 }
